@@ -9,13 +9,14 @@ use Mo qw(build is);
 use Mo::utils qw(check_bool check_number);
 use Mo::utils::CSS qw(check_css_class);
 use Readonly;
+use Scalar::Util qw(looks_like_number);
 
 Readonly::Array our @TYPES => qw(button checkbox color date datetime-local
 	email file hidden image month number password radio range reset search
 	submit tel text time url week);
 Readonly::Array our @STEP_TYPES => qw(date datetime-local month number range time week);
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 has autofocus => (
 	is => 'ro',
@@ -134,7 +135,7 @@ sub BUILD {
 	if (defined $self->{'step'}) {
 		# Value 'any' is valid in step.
 		if ($self->{'step'} ne 'any') {
-			if ($self->{'step'} !~ m/^[-+]?\d+(\.\d+)?$/ms) {
+			if (! looks_like_number($self->{'step'})) {
 				err "Parameter 'step' must be a number or 'any' string.",
 					'Value', $self->{'step'},
 				;
@@ -568,7 +569,9 @@ L<Error::Pure>,
 L<List::Util>,
 L<Mo>,
 L<Mo::utils>,
-L<Readonly>.
+L<Mo::utils::CSS>,
+L<Readonly>,
+L<Scalar::Util>.
 
 =head1 REPOSITORY
 
@@ -588,6 +591,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.12
+0.13
 
 =cut
